Analyzer enum

The type of text analyzer to use for tokenizing and indexing values in an IndexedBox.

  • basic: Tokenizes text into normalized words (tokens).
  • prefix: Tokenizes text into all prefixes of each token, for fast prefix search.
  • ngram: Tokenizes text into all n-grams (substrings of length N), for fuzzy/partial search.
Inheritance
Available extensions

Values

basic → const Analyzer

Tokenizes text into normalized words (tokens).

prefix → const Analyzer

Tokenizes text into all prefixes of each token, for fast prefix search.

ngram → const Analyzer

Tokenizes text into all n-grams (substrings of length N), for fuzzy/partial search.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyzer<T>(String searchableText(T)) TextAnalyzer<T>

Available on Analyzer, provided by the CreateTextAnalyzerExtensions extension

Returns a TextAnalyzer for the given searchableText extractor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Analyzer>
A constant List of the values in this enum, in order of their declaration.