firstWhereOrNull method
Returns the first value matching condition, or null if none found.
Implementation
@override
Future<T?> firstWhereOrNull(bool Function(T item) condition) =>
_executeRead(() => _nativeBox.firstWhereOrNull(condition));
Returns the first value matching condition, or null if none found.
@override
Future<T?> firstWhereOrNull(bool Function(T item) condition) =>
_executeRead(() => _nativeBox.firstWhereOrNull(condition));