BoxType enum

The type of Hive box to create or interact with.

  • regular: A standard, non-lazy, non-isolated Hive box.
  • lazy: A lazy box that loads values on demand, reducing memory usage.
  • isolated: A non-lazy box that operates in a background isolate for concurrency and safety.
  • isolatedLazy: A lazy box that also operates in a background isolate.
Inheritance
Available extensions

Values

regular → const BoxType

Standard, non-lazy, non-isolated Hive box.

lazy → const BoxType

Lazy box that loads values on demand.

isolated → const BoxType

Non-lazy box running in a background isolate.

isolatedLazy → const BoxType

Lazy box running in a background isolate.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

box<K, T>(String name, {HiveCipher? encryptionCipher, bool crashRecovery = true, String? path, String? collection, LogHandler? logger}) Box<K, T>

Available on BoxType, provided by the CreateBoxFromTypeExtensions extension

Creates a Box of this BoxType with the given parameters.
boxConfig(String name, {HiveCipher? encryptionCipher, bool crashRecovery = true, String? path, String? collection, LogHandler? logger}) BoxConfig

Available on BoxType, provided by the CreationExtensionsBoxType extension

Creates a BoxConfig for this BoxType with the given parameters.
createBox<K, T>(String name, {HiveCipher? encryptionCipher, bool crashRecovery = true, String? path, String? collection, LogHandler? logger}) BoxInterface<K, T>

Available on BoxType, provided by the CreationExtensionsBoxType extension

Creates a BoxInterface for this BoxType and the given key/value types.
indexedBox(String name, {HiveCipher? encryptionCipher, bool crashRecovery = true, String? path, String? collection, LogHandler? logger, required String searchableText(T), Analyzer analyzer = Analyzer.prefix, TextAnalyzer<T>? overrideAnalyzer, bool matchAllTokens = true, int tokenCacheCapacity = 512, bool verifyMatches = false, int keyComparator(K a, K b)?}) IndexedBox<K, T>

Available on BoxType, provided by the CreateIndexedBoxFromType extension

Creates an IndexedBox of this BoxType.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BoxType>
A constant List of the values in this enum, in order of their declaration.