GetTypeOfBoxInterfaceExtension<K, T> extension

Extension to determine the BoxType of a BoxInterface at runtime.

This is useful for introspection and for generic code that needs to branch based on the type of box (e.g., for optimizations or diagnostics).

on

Properties

type BoxType

Available on BoxInterface<K, T>, provided by the GetTypeOfBoxInterfaceExtension extension

Returns the BoxType of this box instance.
no setter