markIndexDirty method
Marks the index as dirty to trigger rebuild on next init.
Implementation
Future<void> markIndexDirty() =>
_lock.bypassJournal.operation("MARK_INDEX_DIRTY").run(() async {
await _journal.markDirty();
});
Marks the index as dirty to trigger rebuild on next init.
Future<void> markIndexDirty() =>
_lock.bypassJournal.operation("MARK_INDEX_DIRTY").run(() async {
await _journal.markDirty();
});