CreateHivezBoxFromConfig extension
Extension to create a BoxInterface from a BoxConfig.
This provides a convenient way to instantiate a box using its configuration,
delegating to BoxCreator.boxFromConfig.
- on
Methods
-
createBox<
K, T> () → BoxInterface< K, T> -
Available on BoxConfig, provided by the CreateHivezBoxFromConfig extension
Creates a BoxInterface of the appropriate type for the given key/value types.